==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class BuildStatusOutputFluentImpl<A extends io.fabric8.openshift.api.model.BuildStatusOutputFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.BuildStatusOutputFluent<A>{
  public BuildStatusOutputFluentImpl() {
  }
  public BuildStatusOutputFluentImpl(io.fabric8.openshift.api.model.BuildStatusOutput instance) {
    this.withTo(instance.getTo()); 
  }
  private io.fabric8.openshift.api.model.BuildStatusOutputToBuilder to;
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.BuildStatusOutputTo getTo() {
    return this.to!=null?this.to.build():null;
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputTo buildTo() {
    return this.to!=null?this.to.build():null;
  }
  public A withTo(io.fabric8.openshift.api.model.BuildStatusOutputTo to) {
    _visitables.get("to").remove(this.to);
    if (to!=null){ this.to= new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder(to); _visitables.get("to").add(this.to);} return (A) this;
  }
  public java.lang.Boolean hasTo() {
    return this.to != null;
  }
  public A withNewTo(java.lang.String imageDigest) {
    return (A)withTo(new BuildStatusOutputTo(imageDigest));
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewTo() {
    return new io.fabric8.openshift.api.model.BuildStatusOutputFluentImpl.ToNestedImpl();
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item) {
    return new io.fabric8.openshift.api.model.BuildStatusOutputFluentImpl.ToNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editTo() {
    return withNewToLike(getTo());
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewTo() {
    return withNewToLike(getTo() != null ? getTo(): new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder().build());
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item) {
    return withNewToLike(getTo() != null ? getTo(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BuildStatusOutputFluentImpl that = (BuildStatusOutputFluentImpl) o;
    if (to != null ? !to.equals(that.to) :that.to != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(to,  super.hashCode());
  }
  public class ToNestedImpl<N> extends io.fabric8.openshift.api.model.BuildStatusOutputToFluentImpl<io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<N>> implements io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ToNestedImpl(io.fabric8.openshift.api.model.BuildStatusOutputTo item) {
      this.builder = new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder(this, item);
    }
    ToNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder(this);
    }
    io.fabric8.openshift.api.model.BuildStatusOutputToBuilder builder;
    public N and() {
      return (N) BuildStatusOutputFluentImpl.this.withTo(builder.build());
    }
    public N endTo() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class BuildStatusOutputFluentImpl<A extends io.fabric8.openshift.api.model.BuildStatusOutputFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.BuildStatusOutputFluent<A>{
  public BuildStatusOutputFluentImpl() {
  }
  public BuildStatusOutputFluentImpl(io.fabric8.openshift.api.model.BuildStatusOutput instance) {
    this.withTo(instance.getTo()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.BuildStatusOutputToBuilder to;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.BuildStatusOutputTo getTo() {
    return this.to!=null?this.to.build():null;
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputTo buildTo() {
    return this.to!=null?this.to.build():null;
  }
  public A withTo(io.fabric8.openshift.api.model.BuildStatusOutputTo to) {
    _visitables.get("to").remove(this.to);
    if (to!=null){ this.to= new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder(to); _visitables.get("to").add(this.to);} return (A) this;
  }
  public java.lang.Boolean hasTo() {
    return this.to != null;
  }
  public A withNewTo(java.lang.String imageDigest) {
    return (A)withTo(new BuildStatusOutputTo(imageDigest));
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewTo() {
    return new io.fabric8.openshift.api.model.BuildStatusOutputFluentImpl.ToNestedImpl();
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item) {
    return new io.fabric8.openshift.api.model.BuildStatusOutputFluentImpl.ToNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editTo() {
    return withNewToLike(getTo());
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewTo() {
    return withNewToLike(getTo() != null ? getTo(): new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder().build());
  }
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item) {
    return withNewToLike(getTo() != null ? getTo(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BuildStatusOutputFluentImpl that = (BuildStatusOutputFluentImpl) o;
    if (to != null ? !to.equals(that.to) :that.to != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(to,  additionalProperties,  super.hashCode());
  }
  public class ToNestedImpl<N> extends io.fabric8.openshift.api.model.BuildStatusOutputToFluentImpl<io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<N>> implements io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ToNestedImpl(io.fabric8.openshift.api.model.BuildStatusOutputTo item) {
      this.builder = new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder(this, item);
    }
    ToNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.BuildStatusOutputToBuilder(this);
    }
    io.fabric8.openshift.api.model.BuildStatusOutputToBuilder builder;
    public N and() {
      return (N) BuildStatusOutputFluentImpl.this.withTo(builder.build());
    }
    public N endTo() {
      return and();
    }
    
  }
  
}
